@@ -1,3 +1,28 @@
+/*
+ * Copyright (C) 2008 Tristan Van Berkom
+ * Copyright (C) 2004 Joaquin Cuenca Abela
+ * Copyright (C) 2001, 2002, 2003 Ximian, Inc.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *
+ * Authors:
+ *   Joaquin Cuenca Abela <e98cuenc@yahoo.com>
+ *   Chema Celorio <chema@celorio.com>
+ *   Tristan Van Berkom <tvb@gnome.org>
+ */
+
 #ifndef __GLADE_WIDGET_H__
 #define __GLADE_WIDGET_H__
 
@@ -21,6 +46,8 @@ G_BEGIN_DECLS
 typedef struct _GladeWidgetClass   GladeWidgetClass;
 typedef struct _GladeWidgetPrivate GladeWidgetPrivate;
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GladeWidget, g_object_unref)
+
 struct _GladeWidget
 {
   GInitiallyUnowned parent_instance;
@@ -61,7 +88,7 @@ struct _GladeWidgetClass
  */
 #define GLADE_UNNAMED_PREFIX   "__glade_unnamed_"
 
-#define IS_GLADE_WIDGET_EVENT(event)       \
+#define GLADE_WIDGET_IS_EVENT(event)       \
         ((event) == GDK_BUTTON_PRESS ||    \
          (event) == GDK_BUTTON_RELEASE ||  \
          (event) == GDK_MOTION_NOTIFY)
